# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2019-08-16 09:57
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_message', '0006_emailmessage_emailsendrecord_weixinserviceaccesstoken'),
    ]

    operations = [
        migrations.AddField(
            model_name='emailmessage',
            name='title',
            field=models.CharField(default='aa', max_length=180, verbose_name='\u90ae\u4ef6\u6807\u9898'),
            preserve_default=False,
        ),
        migrations.AlterField(
            model_name='emailmessage',
            name='to_user',
            field=models.TextField(help_text='\u53d1\u9001\u7ed9\u591a\u4eba\u65f6\uff0c\u7528\uff1b\u9694\u79bb\u5f00', null=True, verbose_name='\u53d1\u9001\u7ed9'),
        ),
    ]
