# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2018-12-06 11:51
from __future__ import unicode_literals

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('bee_django_message', '0004_auto_20181206_1915'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='sendrecord',
            options={'ordering': ['-sent_at'], 'permissions': (('view_message_records', 'Can view message records'),)},
        ),
        migrations.RenameField(
            model_name='message',
            old_name='need_replay',
            new_name='need_reply',
        ),
        migrations.RemoveField(
            model_name='message',
            name='is_admin_show',
        ),
        migrations.RemoveField(
            model_name='message',
            name='is_user_show',
        ),
        migrations.AddField(
            model_name='sendrecord',
            name='done_by',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='done_by_user', to=settings.AUTH_USER_MODEL),
        ),
    ]
