# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2018-12-05 13:08
from __future__ import unicode_literals

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_message', '0002_auto_20181205_2103'),
    ]

    operations = [
        migrations.AlterField(
            model_name='sendrecord',
            name='to_user',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='bee_message_to_user', to=settings.AUTH_USER_MODEL, verbose_name='\u53d1\u9001\u7ed9'),
        ),
    ]
