# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2019-11-20 08:27
from __future__ import unicode_literals

import bee_django_richtext.custom_fields
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_message', '0008_auto_20191119_1623'),
    ]

    operations = [
        migrations.AlterField(
            model_name='sendrecord',
            name='info',
            field=bee_django_richtext.custom_fields.RichTextField(app_name='bee_django_message', blank=True, emotion=False, image_max_size=2, img=True, model_name='SendRecord', null=True, text_min_length=5, undo_redo=False, verbose_name='\u5185\u5bb9'),
        ),
    ]
