# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2018-12-06 11:15
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_message', '0003_auto_20181205_2108'),
    ]

    operations = [
        migrations.RenameField(
            model_name='message',
            old_name='is_done',
            new_name='need_done',
        ),
        migrations.RenameField(
            model_name='message',
            old_name='is_replay',
            new_name='need_replay',
        ),
        migrations.AlterField(
            model_name='sendrecord',
            name='done_info',
            field=models.TextField(blank=True, help_text='\u5982\u8bbe\u7f6e\u4e3a\u3010\u53d1\u9001\u56de\u6267\u3011\uff0c\u586b\u5199\u540e\u4f1a\u7ed9\u53d1\u9001\u4eba\u53d1\u7ad9\u5185\u4fe1', null=True, verbose_name='\u5904\u7406\u7ed3\u679c'),
        ),
    ]
