{% extends "bee_django_message/custom_base.html" %}

{% block content %}
    {% include 'bee_django_message/record/_nav.html' %}
    {% include 'bee_django_message/record/_user_record_list.html' %}
{% endblock %}

