# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2019-08-12 10:20
from __future__ import unicode_literals

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('bee_django_message', '0005_auto_20181206_1951'),
    ]

    operations = [
        migrations.CreateModel(
            name='EmailMessage',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=180, verbose_name='\u6d88\u606f\u540d\u79f0')),
                ('to_user', models.CharField(max_length=180)),
                ('info', models.CharField(blank=True, max_length=180, null=True, verbose_name='\u8bf4\u660e')),
                ('identity', models.CharField(help_text='\u6b64\u5b57\u6bb5\u552f\u4e00', max_length=180, unique=True, verbose_name='\u6807\u8bc6\u7b26')),
            ],
            options={
                'ordering': ['id'],
                'db_table': 'bee_django_message_email',
            },
        ),
        migrations.CreateModel(
            name='EmailSendRecord',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('title', models.CharField(max_length=180, null=True)),
                ('content', models.TextField(null=True)),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('email_message', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='email_message', to='bee_django_message.EmailMessage')),
                ('user', models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='email_send_record_user', to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'ordering': ['-created_at'],
                'db_table': 'bee_django_message_email_record',
            },
        ),
        migrations.CreateModel(
            name='WeixinServiceAccessToken',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('token', models.CharField(max_length=180)),
                ('appid', models.CharField(max_length=180)),
                ('appsecrect', models.CharField(max_length=180)),
                ('alias', models.CharField(max_length=180)),
                ('expires', models.IntegerField()),
                ('gettime', models.DateTimeField(auto_now_add=True)),
            ],
            options={
                'db_table': 'bee_django_message_weixin_service_access_token',
            },
        ),
    ]
