# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2018-12-05 13:03
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_message', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='message',
            name='is_done',
            field=models.BooleanField(default=False, help_text='\u5982\u679c\u4e0d\u9700\u540e\u53f0\u663e\u793a\uff0c\u5219\u4e0d\u7528\u586b\u5199', verbose_name='\u662f\u5426\u9700\u8981\u540e\u53f0\u5904\u7406'),
        ),
        migrations.AddField(
            model_name='message',
            name='is_replay',
            field=models.BooleanField(default=False, help_text='\u5982\u679c\u4e0d\u9700\u5904\u7406\uff0c\u5219\u4e0d\u7528\u586b\u5199', verbose_name='\u540e\u53f0\u5904\u7406\u540e\u662f\u5426\u56de\u590d'),
        ),
        migrations.AddField(
            model_name='sendrecord',
            name='done_at',
            field=models.DateTimeField(null=True),
        ),
        migrations.AddField(
            model_name='sendrecord',
            name='done_info',
            field=models.TextField(blank=True, null=True, verbose_name='\u5904\u7406\u7ed3\u679c'),
        ),
        migrations.AddField(
            model_name='sendrecord',
            name='is_done',
            field=models.BooleanField(default=False, verbose_name='\u662f\u5426\u5904\u7406\u8fc7'),
        ),
    ]
