# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2019-11-19 08:23
from __future__ import unicode_literals

import bee_django_richtext.custom_fields
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_message', '0007_auto_20190816_1757'),
    ]

    operations = [
        migrations.AlterField(
            model_name='sendrecord',
            name='info',
            field=bee_django_richtext.custom_fields.RichTextField(blank=True, default='', image_max_size=1, null=True, verbose_name='\u5185\u5bb9'),
        ),
    ]
