# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2019-12-04 09:12
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_message', '0009_auto_20191120_1627'),
    ]

    operations = [
        migrations.RenameField(
            model_name='weixinserviceaccesstoken',
            old_name='appsecrect',
            new_name='appsecret',
        ),
        migrations.AddField(
            model_name='weixinserviceaccesstoken',
            name='scene',
            field=models.IntegerField(choices=[(1, '\u5fae\u4fe1\u670d\u52a1\u53f7'), (2, 'crm\u780d\u4ef7\u5c0f\u7a0b\u5e8f')], default=1, verbose_name='\u4f7f\u7528\u573a\u666f'),
        ),
    ]
