# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2018-10-18 07:10
from __future__ import unicode_literals

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.CreateModel(
            name='Message',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=180, verbose_name='\u6d88\u606f\u540d\u79f0')),
                ('info', models.CharField(blank=True, max_length=180, null=True, verbose_name='\u8bf4\u660e')),
                ('is_user_show', models.BooleanField(default=False, verbose_name='\u5b66\u751f\u9875\u662f\u5426\u663e\u793a')),
                ('is_admin_show', models.BooleanField(default=False, verbose_name='\u7ba1\u7406\u9875\u662f\u5426\u663e\u793a')),
                ('identity', models.CharField(help_text='\u6b64\u5b57\u6bb5\u552f\u4e00', max_length=180, null=True, unique=True, verbose_name='\u6807\u8bc6\u7b26')),
            ],
            options={
                'ordering': ['id'],
                'db_table': 'bee_django_message',
            },
        ),
        migrations.CreateModel(
            name='SendRecord',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('title', models.CharField(max_length=180, verbose_name='\u4e3b\u9898')),
                ('info', models.CharField(blank=True, max_length=180, null=True, verbose_name='\u5185\u5bb9')),
                ('is_view', models.BooleanField(default=False, verbose_name='\u662f\u5426\u770b\u8fc7')),
                ('sent_at', models.DateTimeField(auto_now_add=True, verbose_name='\u53d1\u9001\u65f6\u95f4')),
                ('url', models.CharField(max_length=180, null=True, verbose_name='\u70b9\u51fb\u540e\u8df3\u8f6c\u5230\u7684\u9875\u9762')),
                ('from_user', models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='bee_message_from_user', to=settings.AUTH_USER_MODEL, verbose_name='\u6765\u81ea')),
                ('message', models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='record_message', to='bee_django_message.Message')),
                ('to_user', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='bee_message_to_user', to=settings.AUTH_USER_MODEL, verbose_name='\u53d1\u9001\u7ed9')),
            ],
            options={
                'ordering': ['-sent_at'],
                'db_table': 'bee_django_message_record',
            },
        ),
    ]
